# Generated by Django 3.1.7 on 2021-04-25 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lineup', '0002_auto_20201213_0856'),
    ]

    operations = [
        migrations.AddField(
            model_name='menuitem',
            name='extras',
            field=models.CharField(blank=True, help_text="Add extra-paramaters on menu item eg: icon='fa- fa-user'", max_length=255, null=True, verbose_name='extras'),
        ),
    ]
